nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

RandomNumber

Struct RandomNumber 

#[repr(transparent)]
pub struct RandomNumber(pub u32);
This register contains a random 32 bit number which is computed on demand, at each time it is read

Tuple Fields

0: u32

Implementations

Source

impl RandomNumber

pub const fn random_number(&self) -> u32

This register contains a random 32 bit number which is computed on demand, at each time it is read.

pub const fn set_random_number(&mut self, val: u32)

This register contains a random 32 bit number which is computed on demand, at each time it is read.